@@ -102,6 +102,19 @@ def get_values(i2c_master: I2CMaster, address: int, module_cmd_name: str, idx: i
 def set_values(master: Union[I2CMaster, SupMCUMaster, SupMCUSerialMaster],
                address: int, module_cmd_name: str, idx: int, items: List[TelemetryDataItem],
                response_delay: Optional[float] = None):
+    """
+    Sets the current values of the SupMCU module connected through the provided master
+    to the values in the provided :any:`TelemetryDataItem`s
+
+    :param master: The :any:`I2CMaster` device, :any:`SupMCUMaster`, or :any:`SupMCUSerialMaster` to use to connect the SupMCU module.
+    :param address: The address of the device to request information from. (unused for :any:`SupMCUSerialMaster`)
+    :param module_cmd_name: The module name used in the context of SCPI commands (e.g. DCPS for Desktop CubeSat Power
+                            Supply).
+    :param idx: The telemetry index to grab the information for.
+    :param items: A list of :any:`TelemetryDataItem` objects to supply the values to set.
+    :param response_delay: The amount of time in seconds to wait between I2C Write and read. Can be None, or set
+                            from SupMCUMaster passed in as `i2c_master`.
+    """
     if response_delay is None:
         # None was set by the SupMCU master or the passed in variable.
         response_delay = _DEFAULT_RESPONSE_DELAY
