@@ -15,10 +15,13 @@ import serial
 
 
 class SupMCUSerialMaster:
-    def __init__(self, modules: List[str], ports: List[str], default_timeout: int =.1):
+    """
+    An interface for communication with SupMCU modules via serial.
+    """
+
+    def __init__(self, modules: List[str], ports: List[str], timeout: int =.1):
         self.ports = {}
-        self.timeout = default_timeout
-        ports = [serial.Serial(port, 115200, timeout=default_timeout) for port in ports]
+        ports = [serial.Serial(port, 115200, timeout=timeout) for port in ports]
         for port in ports:
             port.write(b'cd SCPI\n')
             port.readlines()
@@ -33,15 +36,17 @@ class SupMCUSerialMaster:
             bad_mods = [mod for mod in modules if mod not in self.ports.keys()]
             raise IndexError(f"{', '.join(bad_mods)} were not found on the provided ports")
 
-    def send_command(self, mod_name: str, cmd: str, timeout: int = -1):
-        if timeout == -1:
-            timeout = self.timeout
-        self.ports[mod_name].timeout = timeout
+    def send_command(self, mod_name: str, cmd: str):
+        """
+        Sends the SCPI command `cmd` to the named module
+
+        :param module: The name of the module to send the command to.
+        :param cmd: The command to send to the module.
+        """
         if not cmd.endswith('\n'):
             cmd += '\n'
         self.ports[mod_name].write(cmd.encode('ascii'))
         output = self.ports[mod_name].readlines()
-        self.ports[mod_name].timeout = self.timeout
         return self._find_output(output)
 
     def _find_output(self, output: List[str]) -> str:
